# Re-export all the things for convenience
from gfmetadata.axes_pb2 import AxisProto, FallbackProto
from gfmetadata.designers_pb2 import DesignerInfoProto, AvatarProto
from gfmetadata.fonts_public_pb2 import (
    AxisSegmentProto,
    FamilyFallbackProto,
    FamilyProto,
    FontProto,
    GlyphGroupProto,
    SampleTextProto as FamilySampleTextProto,
    SourceFileProto,
    SourceProto,
    TargetProto,
    TargetTypeProto,
)
from gfmetadata.knowledge_pb2 import (
    ContributorsProto,
    KnowledgeProto,
    LessonProto,
    ModuleProto,
    TermProto,
    TopicProto,
)
from gfmetadata.languages_public_pb2 import (
    ExemplarCharsProto,
    LanguageProto,
    RegionProto,
    SampleTextProto,
    ScriptProto,
)

# Re-export so users get the same protobuf version
from google.protobuf import text_format

__all__ = [
    "AxisProto",
    "FallbackProto",
    "DesignerInfoProto",
    "AvatarProto",
    "AxisSegmentProto",
    "FamilyFallbackProto",
    "FamilyProto",
    "FontProto",
    "GlyphGroupProto",
    "FamilySampleTextProto",
    "SourceFileProto",
    "SourceProto",
    "TargetProto",
    "TargetTypeProto",
    "ContributorsProto",
    "KnowledgeProto",
    "LessonProto",
    "ModuleProto",
    "TermProto",
    "TopicProto",
    "ExemplarCharsProto",
    "LanguageProto",
    "RegionProto",
    "SampleTextProto",
    "ScriptProto",
    "text_format",
]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: axes.proto
# Protobuf Python Version: 6.33.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    0,
    '',
    'axes.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\naxes.proto\"\xe6\x01\n\tAxisProto\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x07 \x01(\t\x12\x11\n\tmin_value\x18\x02 \x01(\x02\x12\x15\n\rdefault_value\x18\x03 \x01(\x02\x12\x11\n\tmax_value\x18\x04 \x01(\x02\x12\x11\n\tprecision\x18\x05 \x01(\x05\x12 \n\x08\x66\x61llback\x18\x06 \x03(\x0b\x32\x0e.FallbackProto\x12\x13\n\x0b\x64\x65scription\x18\x08 \x01(\t\x12\x15\n\rfallback_only\x18\t \x01(\x08\x12\x18\n\x10illustration_url\x18\n \x01(\t\"B\n\rFallbackProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02\x12\x14\n\x0c\x64isplay_name\x18\x03 \x01(\t')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'axes_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_AXISPROTO']._serialized_start=15
  _globals['_AXISPROTO']._serialized_end=245
  _globals['_FALLBACKPROTO']._serialized_start=247
  _globals['_FALLBACKPROTO']._serialized_end=313
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: designers.proto
# Protobuf Python Version: 6.33.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    0,
    '',
    'designers.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x64\x65signers.proto\"Q\n\x11\x44\x65signerInfoProto\x12\x10\n\x08\x64\x65signer\x18\x01 \x01(\t\x12\x0c\n\x04link\x18\x02 \x01(\t\x12\x1c\n\x06\x61vatar\x18\x03 \x01(\x0b\x32\x0c.AvatarProto\" \n\x0b\x41vatarProto\x12\x11\n\tfile_name\x18\x01 \x01(\t')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'designers_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DESIGNERINFOPROTO']._serialized_start=19
  _globals['_DESIGNERINFOPROTO']._serialized_end=100
  _globals['_AVATARPROTO']._serialized_start=102
  _globals['_AVATARPROTO']._serialized_end=134
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: fonts_public.proto
# Protobuf Python Version: 6.33.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    0,
    '',
    'fonts_public.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x66onts_public.proto\x12\x13google.fonts_public\"\xc4\x07\n\x0b\x46\x61milyProto\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x10\n\x08\x64\x65signer\x18\x02 \x02(\t\x12\x0f\n\x07license\x18\x03 \x02(\t\x12\x10\n\x08\x63\x61tegory\x18\x04 \x03(\t\x12\x12\n\ndate_added\x18\x05 \x02(\t\x12-\n\x05\x66onts\x18\x06 \x03(\x0b\x32\x1e.google.fonts_public.FontProto\x12\x0f\n\x07\x61liases\x18\x07 \x03(\t\x12\x0f\n\x07subsets\x18\x08 \x03(\t\x12\x19\n\x11ttf_autohint_args\x18\t \x01(\t\x12\x33\n\x04\x61xes\x18\n \x03(\x0b\x32%.google.fonts_public.AxisSegmentProto\x12\x62\n\x1aregistry_default_overrides\x18\x0b \x03(\x0b\x32>.google.fonts_public.FamilyProto.RegistryDefaultOverridesEntry\x12\x30\n\x06source\x18\x0c \x01(\x0b\x32 .google.fonts_public.SourceProto\x12\x0f\n\x07is_noto\x18\r \x01(\x08\x12\x11\n\tlanguages\x18\x0e \x03(\t\x12;\n\tfallbacks\x18\x0f \x03(\x0b\x32(.google.fonts_public.FamilyFallbackProto\x12I\n\rsample_glyphs\x18\x10 \x03(\x0b\x32\x32.google.fonts_public.FamilyProto.SampleGlyphsEntry\x12\x39\n\x0bsample_text\x18\x11 \x01(\x0b\x32$.google.fonts_public.SampleTextProto\x12\x14\n\x0c\x64isplay_name\x18\x12 \x01(\t\x12\x43\n\x15ordered_sample_glyphs\x18\x13 \x03(\x0b\x32$.google.fonts_public.GlyphGroupProto\x12\x14\n\x0cminisite_url\x18\x14 \x01(\t\x12\x16\n\x0eprimary_script\x18\x15 \x01(\t\x12\x18\n\x10primary_language\x18\x16 \x01(\t\x12\x0e\n\x06stroke\x18\x17 \x01(\t\x12\x17\n\x0f\x63lassifications\x18\x19 \x03(\t\x1a?\n\x1dRegistryDefaultOverridesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\x1a\x33\n\x11SampleGlyphsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8a\x01\n\tFontProto\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\r\n\x05style\x18\x02 \x02(\t\x12\x0e\n\x06weight\x18\x03 \x02(\x05\x12\x10\n\x08\x66ilename\x18\x04 \x02(\t\x12\x18\n\x10post_script_name\x18\x05 \x02(\t\x12\x11\n\tfull_name\x18\x06 \x02(\t\x12\x11\n\tcopyright\x18\x07 \x01(\t\"Z\n\x10\x41xisSegmentProto\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12\x11\n\tmin_value\x18\x02 \x01(\x02\x12\x11\n\tmax_value\x18\x04 \x01(\x02J\x04\x08\x03\x10\x04R\rdefault_value\"\xa4\x01\n\x0bSourceProto\x12\x16\n\x0erepository_url\x18\x01 \x01(\t\x12\x0e\n\x06\x62ranch\x18\x05 \x01(\t\x12\x0e\n\x06\x63ommit\x18\x02 \x01(\t\x12\x13\n\x0b\x61rchive_url\x18\x03 \x01(\t\x12\x13\n\x0b\x63onfig_yaml\x18\x06 \x01(\t\x12\x33\n\x05\x66iles\x18\x04 \x03(\x0b\x32$.google.fonts_public.SourceFileProto\"9\n\x0fSourceFileProto\x12\x13\n\x0bsource_file\x18\x01 \x01(\t\x12\x11\n\tdest_file\x18\x02 \x01(\t\"H\n\x0bTargetProto\x12\x39\n\x0btarget_type\x18\x01 \x01(\x0e\x32$.google.fonts_public.TargetTypeProto\"\xcc\x01\n\x13\x46\x61milyFallbackProto\x12:\n\x0b\x61xis_target\x18\x01 \x03(\x0b\x32%.google.fonts_public.AxisSegmentProto\x12\x30\n\x06target\x18\x02 \x03(\x0b\x32 .google.fonts_public.TargetProto\x12\x17\n\x0fsize_adjust_pct\x18\x03 \x01(\x02\x12\x1b\n\x13\x61scent_override_pct\x18\x05 \x01(\x02\x12\x11\n\tlocal_src\x18\x04 \x03(\t\"\x92\x02\n\x0fSampleTextProto\x12\x15\n\rmasthead_full\x18\x01 \x01(\t\x12\x18\n\x10masthead_partial\x18\x02 \x01(\t\x12\x0e\n\x06styles\x18\x03 \x01(\t\x12\x0e\n\x06tester\x18\x04 \x01(\t\x12\x11\n\tposter_sm\x18\x05 \x01(\t\x12\x11\n\tposter_md\x18\x06 \x01(\t\x12\x11\n\tposter_lg\x18\x07 \x01(\t\x12\x13\n\x0bspecimen_48\x18\x08 \x01(\t\x12\x13\n\x0bspecimen_36\x18\t \x01(\t\x12\x13\n\x0bspecimen_32\x18\n \x01(\t\x12\x13\n\x0bspecimen_21\x18\x0b \x01(\t\x12\x13\n\x0bspecimen_16\x18\x0c \x01(\t\x12\x0c\n\x04note\x18\r \x01(\t\"/\n\x0fGlyphGroupProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06glyphs\x18\x02 \x01(\t*\x92\x01\n\x0fTargetTypeProto\x12\x16\n\x12TARGET_UNSPECIFIED\x10\x00\x12\x15\n\x11TARGET_OS_WINDOWS\x10\x01\x12\x11\n\rTARGET_OS_MAC\x10\x02\x12\x13\n\x0fTARGET_OS_LINUX\x10\x03\x12\x15\n\x11TARGET_OS_ANDROID\x10\x04\x12\x11\n\rTARGET_OS_IOS\x10\x05\x42%\n\x16\x63om.google.fonts.protoB\x0b\x46ontsPublic')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fonts_public_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.google.fonts.protoB\013FontsPublic'
  _globals['_FAMILYPROTO_REGISTRYDEFAULTOVERRIDESENTRY']._loaded_options = None
  _globals['_FAMILYPROTO_REGISTRYDEFAULTOVERRIDESENTRY']._serialized_options = b'8\001'
  _globals['_FAMILYPROTO_SAMPLEGLYPHSENTRY']._loaded_options = None
  _globals['_FAMILYPROTO_SAMPLEGLYPHSENTRY']._serialized_options = b'8\001'
  _globals['_TARGETTYPEPROTO']._serialized_start=2077
  _globals['_TARGETTYPEPROTO']._serialized_end=2223
  _globals['_FAMILYPROTO']._serialized_start=44
  _globals['_FAMILYPROTO']._serialized_end=1008
  _globals['_FAMILYPROTO_REGISTRYDEFAULTOVERRIDESENTRY']._serialized_start=892
  _globals['_FAMILYPROTO_REGISTRYDEFAULTOVERRIDESENTRY']._serialized_end=955
  _globals['_FAMILYPROTO_SAMPLEGLYPHSENTRY']._serialized_start=957
  _globals['_FAMILYPROTO_SAMPLEGLYPHSENTRY']._serialized_end=1008
  _globals['_FONTPROTO']._serialized_start=1011
  _globals['_FONTPROTO']._serialized_end=1149
  _globals['_AXISSEGMENTPROTO']._serialized_start=1151
  _globals['_AXISSEGMENTPROTO']._serialized_end=1241
  _globals['_SOURCEPROTO']._serialized_start=1244
  _globals['_SOURCEPROTO']._serialized_end=1408
  _globals['_SOURCEFILEPROTO']._serialized_start=1410
  _globals['_SOURCEFILEPROTO']._serialized_end=1467
  _globals['_TARGETPROTO']._serialized_start=1469
  _globals['_TARGETPROTO']._serialized_end=1541
  _globals['_FAMILYFALLBACKPROTO']._serialized_start=1544
  _globals['_FAMILYFALLBACKPROTO']._serialized_end=1748
  _globals['_SAMPLETEXTPROTO']._serialized_start=1751
  _globals['_SAMPLETEXTPROTO']._serialized_end=2025
  _globals['_GLYPHGROUPPROTO']._serialized_start=2027
  _globals['_GLYPHGROUPPROTO']._serialized_end=2074
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: languages_public.proto
# Protobuf Python Version: 6.33.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    0,
    '',
    'languages_public.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16languages_public.proto\x12\x17google.languages_public\"Q\n\x0bRegionProto\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\npopulation\x18\x03 \x01(\x05\x12\x14\n\x0cregion_group\x18\x04 \x03(\t\"o\n\x0bScriptProto\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nhistorical\x18\x03 \x01(\x08\x12\x11\n\tfictional\x18\x04 \x01(\x08\x12\x0e\n\x06\x66\x61mily\x18\x05 \x01(\t\x12\x0f\n\x07summary\x18\x06 \x01(\t\"\xce\x02\n\rLanguageProto\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08language\x18\x02 \x01(\t\x12\x0e\n\x06script\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x16\n\x0epreferred_name\x18\x05 \x01(\t\x12\x0f\n\x07\x61utonym\x18\x06 \x01(\t\x12\x12\n\npopulation\x18\x07 \x01(\x05\x12\x0e\n\x06region\x18\x08 \x03(\t\x12\x43\n\x0e\x65xemplar_chars\x18\t \x01(\x0b\x32+.google.languages_public.ExemplarCharsProto\x12=\n\x0bsample_text\x18\n \x01(\x0b\x32(.google.languages_public.SampleTextProto\x12\x12\n\nhistorical\x18\x0b \x01(\x08\x12\x0e\n\x06source\x18\x0c \x03(\t\x12\x0c\n\x04note\x18\r \x01(\t\"\x90\x01\n\x12\x45xemplarCharsProto\x12\x0c\n\x04\x62\x61se\x18\x01 \x01(\t\x12\x11\n\tauxiliary\x18\x02 \x01(\t\x12\r\n\x05marks\x18\x03 \x01(\t\x12\x10\n\x08numerals\x18\x04 \x01(\t\x12\x13\n\x0bpunctuation\x18\x05 \x01(\t\x12\r\n\x05index\x18\x06 \x01(\t\x12\x14\n\x0cnot_required\x18\x07 \x01(\t\"\x92\x02\n\x0fSampleTextProto\x12\x15\n\rmasthead_full\x18\x01 \x01(\t\x12\x18\n\x10masthead_partial\x18\x02 \x01(\t\x12\x0e\n\x06styles\x18\x03 \x01(\t\x12\x0e\n\x06tester\x18\x04 \x01(\t\x12\x11\n\tposter_sm\x18\x05 \x01(\t\x12\x11\n\tposter_md\x18\x06 \x01(\t\x12\x11\n\tposter_lg\x18\x07 \x01(\t\x12\x13\n\x0bspecimen_48\x18\x08 \x01(\t\x12\x13\n\x0bspecimen_36\x18\t \x01(\t\x12\x13\n\x0bspecimen_32\x18\n \x01(\t\x12\x13\n\x0bspecimen_21\x18\x0b \x01(\t\x12\x13\n\x0bspecimen_16\x18\x0c \x01(\t\x12\x0c\n\x04note\x18\r \x01(\t')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'languages_public_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_REGIONPROTO']._serialized_start=51
  _globals['_REGIONPROTO']._serialized_end=132
  _globals['_SCRIPTPROTO']._serialized_start=134
  _globals['_SCRIPTPROTO']._serialized_end=245
  _globals['_LANGUAGEPROTO']._serialized_start=248
  _globals['_LANGUAGEPROTO']._serialized_end=582
  _globals['_EXEMPLARCHARSPROTO']._serialized_start=585
  _globals['_EXEMPLARCHARSPROTO']._serialized_end=729
  _globals['_SAMPLETEXTPROTO']._serialized_start=732
  _globals['_SAMPLETEXTPROTO']._serialized_end=1006
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: knowledge.proto
# Protobuf Python Version: 6.33.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    0,
    '',
    'knowledge.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fknowledge.proto\x12\x05\x66onts\"!\n\x0eKnowledgeProto\x12\x0f\n\x07modules\x18\x01 \x03(\t\"N\n\x0bModuleProto\x12\x0f\n\x07\x61lt_ids\x18\x01 \x03(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07\x65xcerpt\x18\x03 \x01(\t\x12\x0f\n\x07lessons\x18\x04 \x03(\t\"+\n\nTopicProto\x12\x0f\n\x07\x61lt_ids\x18\x01 \x03(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xd2\x01\n\x0bLessonProto\x12\x0f\n\x07\x61lt_ids\x18\x01 \x03(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07\x61uthors\x18\x03 \x03(\t\x12\x11\n\treviewers\x18\x04 \x03(\t\x12\x0e\n\x06topics\x18\x05 \x03(\t\x12\x14\n\x0cprev_lessons\x18\x06 \x03(\t\x12\x14\n\x0cnext_lessons\x18\x07 \x03(\t\x12\x15\n\rrelated_terms\x18\x08 \x03(\t\x12\x0f\n\x07\x65xcerpt\x18\t \x01(\t\x12\x1c\n\x14related_content_urls\x18\n \x03(\t\"r\n\tTermProto\x12\x0f\n\x07\x61lt_ids\x18\x01 \x03(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07\x65xcerpt\x18\x03 \x01(\t\x12\x17\n\x0frelated_lessons\x18\x04 \x03(\t\x12\x1c\n\x14related_content_urls\x18\x05 \x03(\t\"\x8d\x01\n\x11\x43ontributorsProto\x12?\n\x0c\x63ontributors\x18\x01 \x03(\x0b\x32).fonts.ContributorsProto.ContributorProto\x1a\x37\n\x10\x43ontributorProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rpersonal_site\x18\x02 \x01(\tB#\n\x16\x63om.google.fonts.protoB\tKnowledge')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'knowledge_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.google.fonts.protoB\tKnowledge'
  _globals['_KNOWLEDGEPROTO']._serialized_start=26
  _globals['_KNOWLEDGEPROTO']._serialized_end=59
  _globals['_MODULEPROTO']._serialized_start=61
  _globals['_MODULEPROTO']._serialized_end=139
  _globals['_TOPICPROTO']._serialized_start=141
  _globals['_TOPICPROTO']._serialized_end=184
  _globals['_LESSONPROTO']._serialized_start=187
  _globals['_LESSONPROTO']._serialized_end=397
  _globals['_TERMPROTO']._serialized_start=399
  _globals['_TERMPROTO']._serialized_end=513
  _globals['_CONTRIBUTORSPROTO']._serialized_start=516
  _globals['_CONTRIBUTORSPROTO']._serialized_end=657
  _globals['_CONTRIBUTORSPROTO_CONTRIBUTORPROTO']._serialized_start=602
  _globals['_CONTRIBUTORSPROTO_CONTRIBUTORPROTO']._serialized_end=657
# @@protoc_insertion_point(module_scope)
